# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: catalog/book_instance.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='catalog/book_instance.proto',
  package='catalog',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x1b\x63\x61talog/book_instance.proto\x12\x07\x63\x61talog\"m\n\x0c\x42ookInstance\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04\x62ook\x18\x02 \x01(\x05\x12\x0f\n\x07imprint\x18\x03 \x01(\t\x12\x10\n\x08\x64ue_back\x18\x04 \x01(\t\x12\x10\n\x08\x62orrower\x18\x05 \x01(\x05\x12\x0e\n\x06status\x18\x06 \x01(\t\"3\n\x13\x42ookInstanceRenewal\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x64ue_back\x18\x02 \x01(\t\"-\n\x19MyBookInstanceListRequest\x12\x10\n\x08\x62orrower\x18\x01 \x01(\x05\"\x19\n\x17\x42ookInstanceListRequest2\xa0\x02\n\x16\x42ookInstanceController\x12\x43\n\x04List\x12 .catalog.BookInstanceListRequest\x1a\x15.catalog.BookInstance\"\x00\x30\x01\x12\x38\n\x06\x43reate\x12\x15.catalog.BookInstance\x1a\x15.catalog.BookInstance\"\x00\x12G\n\x06MyList\x12\".catalog.MyBookInstanceListRequest\x1a\x15.catalog.BookInstance\"\x00\x30\x01\x12>\n\x05Renew\x12\x1c.catalog.BookInstanceRenewal\x1a\x15.catalog.BookInstance\"\x00\x62\x06proto3'
)




_BOOKINSTANCE = _descriptor.Descriptor(
  name='BookInstance',
  full_name='catalog.BookInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='catalog.BookInstance.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='book', full_name='catalog.BookInstance.book', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='imprint', full_name='catalog.BookInstance.imprint', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='due_back', full_name='catalog.BookInstance.due_back', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='borrower', full_name='catalog.BookInstance.borrower', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='catalog.BookInstance.status', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=149,
)


_BOOKINSTANCERENEWAL = _descriptor.Descriptor(
  name='BookInstanceRenewal',
  full_name='catalog.BookInstanceRenewal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='catalog.BookInstanceRenewal.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='due_back', full_name='catalog.BookInstanceRenewal.due_back', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=202,
)


_MYBOOKINSTANCELISTREQUEST = _descriptor.Descriptor(
  name='MyBookInstanceListRequest',
  full_name='catalog.MyBookInstanceListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='borrower', full_name='catalog.MyBookInstanceListRequest.borrower', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=204,
  serialized_end=249,
)


_BOOKINSTANCELISTREQUEST = _descriptor.Descriptor(
  name='BookInstanceListRequest',
  full_name='catalog.BookInstanceListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=276,
)

DESCRIPTOR.message_types_by_name['BookInstance'] = _BOOKINSTANCE
DESCRIPTOR.message_types_by_name['BookInstanceRenewal'] = _BOOKINSTANCERENEWAL
DESCRIPTOR.message_types_by_name['MyBookInstanceListRequest'] = _MYBOOKINSTANCELISTREQUEST
DESCRIPTOR.message_types_by_name['BookInstanceListRequest'] = _BOOKINSTANCELISTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BookInstance = _reflection.GeneratedProtocolMessageType('BookInstance', (_message.Message,), {
  'DESCRIPTOR' : _BOOKINSTANCE,
  '__module__' : 'catalog.book_instance_pb2'
  # @@protoc_insertion_point(class_scope:catalog.BookInstance)
  })
_sym_db.RegisterMessage(BookInstance)

BookInstanceRenewal = _reflection.GeneratedProtocolMessageType('BookInstanceRenewal', (_message.Message,), {
  'DESCRIPTOR' : _BOOKINSTANCERENEWAL,
  '__module__' : 'catalog.book_instance_pb2'
  # @@protoc_insertion_point(class_scope:catalog.BookInstanceRenewal)
  })
_sym_db.RegisterMessage(BookInstanceRenewal)

MyBookInstanceListRequest = _reflection.GeneratedProtocolMessageType('MyBookInstanceListRequest', (_message.Message,), {
  'DESCRIPTOR' : _MYBOOKINSTANCELISTREQUEST,
  '__module__' : 'catalog.book_instance_pb2'
  # @@protoc_insertion_point(class_scope:catalog.MyBookInstanceListRequest)
  })
_sym_db.RegisterMessage(MyBookInstanceListRequest)

BookInstanceListRequest = _reflection.GeneratedProtocolMessageType('BookInstanceListRequest', (_message.Message,), {
  'DESCRIPTOR' : _BOOKINSTANCELISTREQUEST,
  '__module__' : 'catalog.book_instance_pb2'
  # @@protoc_insertion_point(class_scope:catalog.BookInstanceListRequest)
  })
_sym_db.RegisterMessage(BookInstanceListRequest)



_BOOKINSTANCECONTROLLER = _descriptor.ServiceDescriptor(
  name='BookInstanceController',
  full_name='catalog.BookInstanceController',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=279,
  serialized_end=567,
  methods=[
  _descriptor.MethodDescriptor(
    name='List',
    full_name='catalog.BookInstanceController.List',
    index=0,
    containing_service=None,
    input_type=_BOOKINSTANCELISTREQUEST,
    output_type=_BOOKINSTANCE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='catalog.BookInstanceController.Create',
    index=1,
    containing_service=None,
    input_type=_BOOKINSTANCE,
    output_type=_BOOKINSTANCE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='MyList',
    full_name='catalog.BookInstanceController.MyList',
    index=2,
    containing_service=None,
    input_type=_MYBOOKINSTANCELISTREQUEST,
    output_type=_BOOKINSTANCE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Renew',
    full_name='catalog.BookInstanceController.Renew',
    index=3,
    containing_service=None,
    input_type=_BOOKINSTANCERENEWAL,
    output_type=_BOOKINSTANCE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_BOOKINSTANCECONTROLLER)

DESCRIPTOR.services_by_name['BookInstanceController'] = _BOOKINSTANCECONTROLLER

# @@protoc_insertion_point(module_scope)
