# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: catalog/language.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='catalog/language.proto',
  package='catalog',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x16\x63\x61talog/language.proto\x12\x07\x63\x61talog\"$\n\x08Language\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x15\n\x13LanguageListRequest2Q\n\x12LanguageController\x12;\n\x04List\x12\x1c.catalog.LanguageListRequest\x1a\x11.catalog.Language\"\x00\x30\x01\x62\x06proto3'
)




_LANGUAGE = _descriptor.Descriptor(
  name='Language',
  full_name='catalog.Language',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='catalog.Language.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='catalog.Language.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35,
  serialized_end=71,
)


_LANGUAGELISTREQUEST = _descriptor.Descriptor(
  name='LanguageListRequest',
  full_name='catalog.LanguageListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=94,
)

DESCRIPTOR.message_types_by_name['Language'] = _LANGUAGE
DESCRIPTOR.message_types_by_name['LanguageListRequest'] = _LANGUAGELISTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Language = _reflection.GeneratedProtocolMessageType('Language', (_message.Message,), {
  'DESCRIPTOR' : _LANGUAGE,
  '__module__' : 'catalog.language_pb2'
  # @@protoc_insertion_point(class_scope:catalog.Language)
  })
_sym_db.RegisterMessage(Language)

LanguageListRequest = _reflection.GeneratedProtocolMessageType('LanguageListRequest', (_message.Message,), {
  'DESCRIPTOR' : _LANGUAGELISTREQUEST,
  '__module__' : 'catalog.language_pb2'
  # @@protoc_insertion_point(class_scope:catalog.LanguageListRequest)
  })
_sym_db.RegisterMessage(LanguageListRequest)



_LANGUAGECONTROLLER = _descriptor.ServiceDescriptor(
  name='LanguageController',
  full_name='catalog.LanguageController',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=96,
  serialized_end=177,
  methods=[
  _descriptor.MethodDescriptor(
    name='List',
    full_name='catalog.LanguageController.List',
    index=0,
    containing_service=None,
    input_type=_LANGUAGELISTREQUEST,
    output_type=_LANGUAGE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_LANGUAGECONTROLLER)

DESCRIPTOR.services_by_name['LanguageController'] = _LANGUAGECONTROLLER

# @@protoc_insertion_point(module_scope)
