# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: catalog/author.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='catalog/author.proto',
  package='catalog',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x14\x63\x61talog/author.proto\x12\x07\x63\x61talog\x1a\x1bgoogle/protobuf/empty.proto\"i\n\x06\x41uthor\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nfirst_name\x18\x02 \x01(\t\x12\x11\n\tlast_name\x18\x03 \x01(\t\x12\x15\n\rdate_of_birth\x18\x04 \x01(\t\x12\x15\n\rdate_of_death\x18\x05 \x01(\t\"\x13\n\x11\x41uthorListRequest\"#\n\x15\x41uthorRetrieveRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x32\x9c\x02\n\x10\x41uthorController\x12\x37\n\x04List\x12\x1a.catalog.AuthorListRequest\x1a\x0f.catalog.Author\"\x00\x30\x01\x12,\n\x06\x43reate\x12\x0f.catalog.Author\x1a\x0f.catalog.Author\"\x00\x12=\n\x08Retrieve\x12\x1e.catalog.AuthorRetrieveRequest\x1a\x0f.catalog.Author\"\x00\x12,\n\x06Update\x12\x0f.catalog.Author\x1a\x0f.catalog.Author\"\x00\x12\x34\n\x07\x44\x65stroy\x12\x0f.catalog.Author\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_AUTHOR = _descriptor.Descriptor(
  name='Author',
  full_name='catalog.Author',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='catalog.Author.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_name', full_name='catalog.Author.first_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_name', full_name='catalog.Author.last_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_of_birth', full_name='catalog.Author.date_of_birth', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_of_death', full_name='catalog.Author.date_of_death', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=167,
)


_AUTHORLISTREQUEST = _descriptor.Descriptor(
  name='AuthorListRequest',
  full_name='catalog.AuthorListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=188,
)


_AUTHORRETRIEVEREQUEST = _descriptor.Descriptor(
  name='AuthorRetrieveRequest',
  full_name='catalog.AuthorRetrieveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='catalog.AuthorRetrieveRequest.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=225,
)

DESCRIPTOR.message_types_by_name['Author'] = _AUTHOR
DESCRIPTOR.message_types_by_name['AuthorListRequest'] = _AUTHORLISTREQUEST
DESCRIPTOR.message_types_by_name['AuthorRetrieveRequest'] = _AUTHORRETRIEVEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Author = _reflection.GeneratedProtocolMessageType('Author', (_message.Message,), {
  'DESCRIPTOR' : _AUTHOR,
  '__module__' : 'catalog.author_pb2'
  # @@protoc_insertion_point(class_scope:catalog.Author)
  })
_sym_db.RegisterMessage(Author)

AuthorListRequest = _reflection.GeneratedProtocolMessageType('AuthorListRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORLISTREQUEST,
  '__module__' : 'catalog.author_pb2'
  # @@protoc_insertion_point(class_scope:catalog.AuthorListRequest)
  })
_sym_db.RegisterMessage(AuthorListRequest)

AuthorRetrieveRequest = _reflection.GeneratedProtocolMessageType('AuthorRetrieveRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORRETRIEVEREQUEST,
  '__module__' : 'catalog.author_pb2'
  # @@protoc_insertion_point(class_scope:catalog.AuthorRetrieveRequest)
  })
_sym_db.RegisterMessage(AuthorRetrieveRequest)



_AUTHORCONTROLLER = _descriptor.ServiceDescriptor(
  name='AuthorController',
  full_name='catalog.AuthorController',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=228,
  serialized_end=512,
  methods=[
  _descriptor.MethodDescriptor(
    name='List',
    full_name='catalog.AuthorController.List',
    index=0,
    containing_service=None,
    input_type=_AUTHORLISTREQUEST,
    output_type=_AUTHOR,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='catalog.AuthorController.Create',
    index=1,
    containing_service=None,
    input_type=_AUTHOR,
    output_type=_AUTHOR,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Retrieve',
    full_name='catalog.AuthorController.Retrieve',
    index=2,
    containing_service=None,
    input_type=_AUTHORRETRIEVEREQUEST,
    output_type=_AUTHOR,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='catalog.AuthorController.Update',
    index=3,
    containing_service=None,
    input_type=_AUTHOR,
    output_type=_AUTHOR,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Destroy',
    full_name='catalog.AuthorController.Destroy',
    index=4,
    containing_service=None,
    input_type=_AUTHOR,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTHORCONTROLLER)

DESCRIPTOR.services_by_name['AuthorController'] = _AUTHORCONTROLLER

# @@protoc_insertion_point(module_scope)
